@@ -12,7 +12,10 @@ int removedb(const char *iface, const char *dirname);
 void cleanhours(void);
 void rotatedays(void);
 void rotatemonths(void);
-
+void cleartop10(const char *iface, const char *dirname);
+void rebuilddbtotal(const char *iface, const char *dirname);
+int validatedb(void);
+int importdb(const char *filename);
 
 /* version 1.0 database format aka db v1 */
 typedef struct {
