@@ -10,7 +10,7 @@ void showtop(void);
 void showweeks(void);
 void showhours(void);
 void showoneline(void);
-void dumpdb(void);
+void exportdb(void);
 void showbar(uint64_t rx, int rxk, uint64_t tx, int txk, uint64_t max, int len);
 void indent(int i);
 
