@@ -7,11 +7,13 @@ int kerneltest(void);
 int spacecheck(char *path);
 void sighandler(int);
 int getbtime(void);
-void addtraffic(uint64_t *destmb, int *destkb, uint64_t srcmb, int srckb);
 char *getvalue(uint64_t mb, uint64_t kb, int len, int type);
 char *getrate(uint64_t mb, uint64_t kb, uint32_t interval, int len);
+char *gettrafficrate(uint64_t bytes, uint32_t interval, int len);
 uint64_t getscale(uint64_t kb);
 char *getunit(int index);
 char *getrateunit(int unit, int index);
+uint32_t getunitdivider(int unit, int index);
+char *getratestring(float rate, int len, int declen, int unit);
 
 #endif
